#
# spec file for package switcheroo-control
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           switcheroo-control
Version:        2.6
Release:        1.5
Summary:        D-Bus service to check the availability of dual-GPU
License:        GPL-3.0-only
Group:          Hardware/Other
URL:            https://gitlab.freedesktop.org/hadess/switcheroo-control
Source0:        https://gitlab.freedesktop.org/hadess/switcheroo-control/-/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Patch0:         harden_switcheroo-control.service.patch
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.50
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 232
BuildRequires:  pkgconfig(udev)
%{?systemd_requires}
# SECTION For tests
BuildRequires:  %{python_module dbus-python}
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(umockdev-1.0)
# /SECTION

%description
switcheroo-control is a D-Bus service to check the availability of dual-GPU.

%package doc
Summary:        Documentation for %{name}
Group:          Hardware/Other
BuildArch:      noarch

%description doc
This package contains the documentation for %{name}.

%prep
%setup -q
%patch0 -p1

%build
%meson \
   -Dsystemdsystemunitdir=%{_unitdir} \
   -Dhwdbdir=%{_udevhwdbdir} \
   -Dgtk_doc=true

%meson_build

%install
%meson_install

%check
%meson_test

%pre
%service_add_pre switcheroo-control.service

%post
%service_add_post switcheroo-control.service
%udev_hwdb_update

%preun
%service_del_preun switcheroo-control.service

%postun
%service_del_postun switcheroo-control.service
%udev_hwdb_update

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/switcherooctl
%{_libexecdir}/switcheroo-control
%{_mandir}/man1/switcherooctl.1%{?ext_man}
%{_unitdir}/switcheroo-control.service
%{_udevhwdbdir}/30-pci-intel-gpu.hwdb
%{_datadir}/dbus-1/system.d/net.hadess.SwitcherooControl.conf

%files doc
%doc %{_datadir}/gtk-doc/html/%{name}/

%changelog
* Mon Jul  4 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6:
  * Remove the recently added support for setting the GPU for
    Vulkan apps as this broke sandboxed Vulkan apps.
  * Fix for non-x86 platforms not having a default GPU.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5:
  * Add support for setting the GPU to use for Vulkan apps, on
    systems with heterogenous GPUs.
  * Fix "--gpu" option not working as documented.
  * Install the D-Bus configuration file in the correct location.
- Adapt dbus conf file location in keeping with upstream (requires
  re-evaluation by security team bsc#1199065).
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_switcheroo-control.service.patch
* Tue Jan  5 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4:
  * Fix the cleaned-up name of some video cards not being picked
    up.
  * Add a test suite.
- BuildRequires: pkgconfig(umockdev), python-dbus-python, and
  python-rpm-macros for unit test run as part of %%check.
- meson >= 0.50 is required; update BuildRequires accordingly.
* Tue Jul 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.3:
  * Fix the path to the interpreter for the switcherooctl tool
    added in 2.2.
- Changes from version 2.2:
  * Port build system to meson.
  * Add a command-line utility to launch specific commands on a
    specific GPU, or the first discrete one.
- Adapt to meson build system; drop autoconf, automake from
  BuildRequires and add meson.
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1:
  * Fix the wrong data type being advertised in the introspection
    XML for the GPUs property, which lead to incorrect
    auto-generated code
  * Fix a potential assertion on startup.
* Sat Nov 23 2019 Dingzhong Chen <wsxy162@gmail.com>
- Update to version 2.0
  + This release adds a number of new properties to list GPUs,
    figure out how to launch OpenGL client on specific GPUs, and
    figure out which one is the default, in a way that supports the
    stock GPU drivers as well as the NVidia proprietary drivers.
  + The service file itself also makes use of systemd's hardening
    features.
  + Note that the API was extended in a backwards compatible way.
- Change the repo URL.
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.3.1
  + Fix Secure Boot work-around to not misdetect any system as
    being dual-GPU and error out when it wasn't
- Changes from version 1.3:
  + Work-around lack of access to vga_switcheroo when booting with
    SecureBoot enabled
  + Work-around a possible kernel deadlock on boot
  + Install binary in $libexecdir
* Tue Feb 20 2018 luc14n0@linuxmail.org
- Add systemd-rpm-macros BuildRequires and service_add_*
  pre/post/preun/postun scriptlets for switcheroo-control.service
  to comply with openSUSE's Guidelines (boo#1096823).
- Pass --with-systemdsystemunitdir=%%{_unitdir} parameter to
  configure to correct the systemd unit file's location.
- Adopt the use of %%make_install macro rather than raw make
  command, following the best practices.
* Fri Sep 22 2017 badshah400@gmail.com
- Update to version 1.2:
  + Fix API documentation not being part of the tarball.
* Wed Aug 23 2017 badshah400@gmail.com
- Change License tag to GPL-3.0 instead of GPL-3.0+ (see legal
  review for https://build.opensuse.org/request/show/507370).
* Sun Jun 25 2017 badshah400@gmail.com
- DBus service has been reviewed and approved (boo#1034309),
  remove corresponding entry from rpmlintrc.
* Sat Apr 15 2017 badshah400@gmail.com
- Initial package.
- Add %%{name}-rpmlintrc file to filter out warning about missing
  man file for binary (upstream does not provide it) and set
  badness for 'suse-dbus-unauthorized-service' to zero until
  security review approves the dbus service (see boo#1034309).
